#ifndef GAP_BUILD_VERSION
#define GAP_BUILD_VERSION  "4.8.8, 20-Aug-2017, build"
#define GAP_BUILD_DATETIME "2017-11-17 19:05:37 (MST)"
#endif
